@@ -2,13 +2,13 @@ import logging
 from typing import Type, Optional
 
 from langchain_core.tools import ToolException
-from pydantic import BaseModel
+from pydantic import BaseModel, model_validator
 
 from codemie_tools.base.codemie_tool import CodeMieTool
 from codemie_tools.base.utils import parse_to_dict
+from .keycloak_client import KeycloakClient
 from .models import KeycloakConfig, KeycloakToolInput
 from .tools_vars import KEYCLOAK_TOOL
-from .keycloak_client import KeycloakClient
 
 logger = logging.getLogger(__name__)
 
@@ -22,16 +22,20 @@ class KeycloakTool(CodeMieTool):
     description: str = KEYCLOAK_TOOL.description
     args_schema: Type[BaseModel] = KeycloakToolInput
 
-    def __init__(self, config: KeycloakConfig):
-        """Initialize the tool with configuration."""
-        super().__init__(config=config)
-        self.client = KeycloakClient(
-            base_url=config.base_url,
-            realm=config.realm,
-            client_id=config.client_id,
-            client_secret=config.client_secret,
-            timeout=config.timeout
-        )
+    @model_validator(mode='after')
+    def initialize_client(self) -> 'KeycloakTool':
+        """Initialize the Keycloak client with configuration."""
+        # Only initialize if all required fields are present
+        if (self.config.base_url and self.config.realm and
+            self.config.client_id and self.config.client_secret):
+            self.client = KeycloakClient(
+                base_url=self.config.base_url,
+                realm=self.config.realm,
+                client_id=self.config.client_id,
+                client_secret=self.config.client_secret,
+                timeout=self.config.timeout
+            )
+        return self
 
     def execute(
         self,
