@@ -3,7 +3,7 @@ from typing import List
 
 from codemie_tools.access_management.keycloak.tools import KeycloakTool
 from codemie_tools.access_management.keycloak.tools_vars import KEYCLOAK_TOOL
-from codemie_tools.base.base_toolkit import BaseToolkit, DiscoverableToolkit
+from codemie_tools.base.base_toolkit import DiscoverableToolkit
 from codemie_tools.base.models import ToolKit, ToolSet, Tool
 
 logger = logging.getLogger(__name__)
