@@ -7,8 +7,9 @@ from codemie_tools.azure_devops.wiki.tools import (
     GetWikiPageByIdTool,
     DeletePageByPathTool,
     DeletePageByIdTool,
+    CreateWikiPageTool,
     ModifyWikiPageTool,
-    RenameWikiPageTool
+    RenameWikiPageTool,
 )
 from codemie_tools.azure_devops.wiki.tools_vars import (
     GET_WIKI_TOOL,
@@ -16,8 +17,9 @@ from codemie_tools.azure_devops.wiki.tools_vars import (
     GET_WIKI_PAGE_BY_ID_TOOL,
     DELETE_PAGE_BY_PATH_TOOL,
     DELETE_PAGE_BY_ID_TOOL,
+    CREATE_WIKI_PAGE_TOOL,
     MODIFY_WIKI_PAGE_TOOL,
-    RENAME_WIKI_PAGE_TOOL
+    RENAME_WIKI_PAGE_TOOL,
 )
 from codemie_tools.base.base_toolkit import BaseToolkit
 from codemie_tools.base.models import ToolKit, ToolSet, Tool
@@ -31,6 +33,7 @@ class AzureDevOpsWikiToolkitUI(ToolKit):
         Tool.from_metadata(GET_WIKI_PAGE_BY_ID_TOOL),
         Tool.from_metadata(DELETE_PAGE_BY_PATH_TOOL),
         Tool.from_metadata(DELETE_PAGE_BY_ID_TOOL),
+        Tool.from_metadata(CREATE_WIKI_PAGE_TOOL),
         Tool.from_metadata(MODIFY_WIKI_PAGE_TOOL),
         Tool.from_metadata(RENAME_WIKI_PAGE_TOOL),
     ]
@@ -49,10 +52,11 @@ class AzureDevOpsWikiToolkit(BaseToolkit):
                 Tool.from_metadata(GET_WIKI_PAGE_BY_ID_TOOL),
                 Tool.from_metadata(DELETE_PAGE_BY_PATH_TOOL),
                 Tool.from_metadata(DELETE_PAGE_BY_ID_TOOL),
+                Tool.from_metadata(CREATE_WIKI_PAGE_TOOL),
                 Tool.from_metadata(MODIFY_WIKI_PAGE_TOOL),
                 Tool.from_metadata(RENAME_WIKI_PAGE_TOOL),
             ],
-            settings_config=True
+            settings_config=True,
         ).model_dump()
 
     def get_tools(self) -> list:
@@ -62,8 +66,9 @@ class AzureDevOpsWikiToolkit(BaseToolkit):
             GetWikiPageByIdTool(config=self.ado_config),
             DeletePageByPathTool(config=self.ado_config),
             DeletePageByIdTool(config=self.ado_config),
+            CreateWikiPageTool(config=self.ado_config),
             ModifyWikiPageTool(config=self.ado_config),
-            RenameWikiPageTool(config=self.ado_config)
+            RenameWikiPageTool(config=self.ado_config),
         ]
         return tools
 
