@@ -22,6 +22,7 @@ from codemie_tools.azure_devops.wiki.models import (
     GetPageByPathInput,
     GetPageByIdInput,
     ModifyPageInput,
+    CreatePageInput,
     RenamePageInput,
 )
 from codemie_tools.azure_devops.wiki.tools_vars import (
@@ -30,6 +31,7 @@ from codemie_tools.azure_devops.wiki.tools_vars import (
     GET_WIKI_PAGE_BY_ID_TOOL,
     DELETE_PAGE_BY_PATH_TOOL,
     DELETE_PAGE_BY_ID_TOOL,
+    CREATE_WIKI_PAGE_TOOL,
     MODIFY_WIKI_PAGE_TOOL,
     RENAME_WIKI_PAGE_TOOL,
 )
@@ -39,6 +41,9 @@ from codemie_tools.base.codemie_tool import CodeMieTool, logger
 if not os.environ.get("AZURE_DEVOPS_CACHE_DIR", None):
     os.environ["AZURE_DEVOPS_CACHE_DIR"] = ""
 
+# Constants for error messages
+INVALID_VERSION_ERROR = "The version '{0}' either is invalid or does not exist."
+
 
 class BaseAzureDevOpsWikiTool(CodeMieTool):
     """Base class for Azure DevOps Wiki tools."""
@@ -92,6 +97,71 @@ class BaseAzureDevOpsWikiTool(CodeMieTool):
         """Set the Azure DevOps core client (useful for testing)."""
         self.__core_client = value
 
+    def _extract_page_id_from_path(self, page_name: str) -> Optional[int]:
+        """
+        Extract page ID from path format like '/10330/This-is-sub-page'.
+
+        Returns page ID if found, None otherwise.
+        """
+        if not page_name or not page_name.startswith("/"):
+            return None
+
+        parts = page_name.lstrip("/").split("/", 1)
+        if parts and parts[0].isdigit():
+            return int(parts[0])
+        return None
+
+    def _get_full_path_from_id(self, wiki_identified: str, page_id: int) -> str:
+        """
+        Get the full hierarchical path of a page using its ID.
+
+        Returns the full path like '/Parent/Child/Page'.
+        """
+        try:
+            page = self._client.get_page_by_id(
+                project=self.config.project,
+                wiki_identifier=wiki_identified,
+                id=page_id,
+                include_content=False,
+            )
+            return page.page.path
+        except Exception as e:
+            logger.error(f"Failed to get page path from ID {page_id}: {str(e)}")
+            raise ToolException(f"Failed to get page path from ID {page_id}: {str(e)}")
+
+    def _get_project_id(self) -> Optional[str]:
+        """Get project ID from project name."""
+        projects = self._core_client.get_projects()
+        for project in projects:
+            if project.name == self.config.project:
+                return project.id
+        return None
+
+    def _create_wiki_if_not_exists(self, wiki_identified: str) -> Optional[str]:
+        """Create wiki if it doesn't exist."""
+        all_wikis = [wiki.name for wiki in self._client.get_all_wikis(project=self.config.project)]
+        if wiki_identified in all_wikis:
+            return None
+
+        logger.info(f"Wiki name '{wiki_identified}' doesn't exist. New wiki will be created.")
+        try:
+            project_id = self._get_project_id()
+            if not project_id:
+                return "Project ID has not been found."
+
+            self._client.create_wiki(
+                project=self.config.project,
+                wiki_create_params=WikiCreateParametersV2(
+                    name=wiki_identified, project_id=project_id
+                ),
+            )
+            logger.info(f"Wiki '{wiki_identified}' has been created")
+            return None
+        except Exception as create_wiki_e:
+            error_msg = f"Unable to create new wiki due to error: {create_wiki_e}"
+            logger.error(error_msg)
+            return error_msg
+
 
 class GetWikiTool(BaseAzureDevOpsWikiTool):
     """Tool to get information about a wiki in Azure DevOps."""
@@ -122,6 +192,17 @@ class GetWikiPageByPathTool(BaseAzureDevOpsWikiTool):
     def execute(self, wiki_identified: str, page_name: str):
         """Extract ADO wiki page content."""
         try:
+            # Try to extract page ID from path format like '/10330/This-is-sub-page'
+            page_id = self._extract_page_id_from_path(page_name)
+
+            if page_id is not None:
+                # Get full hierarchical path using page ID
+                logger.info(f"Extracted page ID {page_id} from path, discovering full path...")
+                full_path = self._get_full_path_from_id(wiki_identified, page_id)
+                logger.info(f"Discovered full path: {full_path}")
+                page_name = full_path
+
+            # Get page content using the (possibly resolved) path
             page = self._client.get_page(
                 project=self.config.project,
                 wiki_identifier=wiki_identified,
@@ -166,6 +247,17 @@ class DeletePageByPathTool(BaseAzureDevOpsWikiTool):
     def execute(self, wiki_identified: str, page_name: str):
         """Delete ADO wiki page by path."""
         try:
+            # Try to extract page ID from path format like '/10330/This-is-sub-page'
+            page_id = self._extract_page_id_from_path(page_name)
+
+            if page_id is not None:
+                # Get full hierarchical path using page ID
+                logger.info(f"Extracted page ID {page_id} from path, discovering full path...")
+                full_path = self._get_full_path_from_id(wiki_identified, page_id)
+                logger.info(f"Discovered full path: {full_path}")
+                page_name = full_path
+
+            # Delete page using the (possibly resolved) path
             self._client.delete_page(
                 project=self.config.project, wiki_identifier=wiki_identified, path=page_name
             )
@@ -201,6 +293,22 @@ class RenameWikiPageTool(BaseAzureDevOpsWikiTool):
     description: str = RENAME_WIKI_PAGE_TOOL.description
     args_schema: Type[BaseModel] = RenamePageInput
 
+    def _verify_page_exists(self, wiki_identified: str, page_path: str) -> None:
+        """
+        Verify that the page exists.
+
+        Raises ToolException if page doesn't exist.
+        """
+        try:
+            self._client.get_page(
+                project=self.config.project, wiki_identifier=wiki_identified, path=page_path
+            )
+            logger.info(f"Page '{page_path}' exists and can be renamed")
+        except Exception as e:
+            error_msg = f"Page '{page_path}' not found. Cannot rename a page that doesn't exist. Error: {str(e)}"
+            logger.error(error_msg)
+            raise ToolException(error_msg)
+
     def execute(
         self,
         wiki_identified: str,
@@ -211,6 +319,33 @@ class RenameWikiPageTool(BaseAzureDevOpsWikiTool):
     ):
         """Rename page in Azure DevOps wiki from old page name to new page name."""
         try:
+            # Try to extract page ID from old path format like '/10330/This-is-sub-page'
+            page_id = self._extract_page_id_from_path(old_page_name)
+
+            if page_id is not None:
+                # Get full hierarchical path using page ID
+                logger.info(f"Extracted page ID {page_id} from path, discovering full path...")
+                full_path = self._get_full_path_from_id(wiki_identified, page_id)
+                logger.info(f"Discovered full path: {full_path}")
+                old_page_name = full_path
+
+            # Verify the page exists before attempting rename
+            self._verify_page_exists(wiki_identified, old_page_name)
+
+            # Construct new path based on input format
+            if not new_page_name.startswith("/"):
+                # If new_page_name is just a name (not a path), keep it in the same parent directory
+                # Extract parent path from old_page_name
+                parent_path = "/".join(old_page_name.rsplit("/", 1)[:-1])
+                if parent_path:
+                    new_page_name = f"{parent_path}/{new_page_name}"
+                else:
+                    new_page_name = f"/{new_page_name}"
+            # If new_page_name starts with "/", use it as-is (full path move)
+
+            logger.info(f"Renaming page from '{old_page_name}' to '{new_page_name}'")
+
+            # Rename the page
             try:
                 result = self._client.create_page_move(
                     project=self.config.project,
@@ -229,7 +364,7 @@ class RenameWikiPageTool(BaseAzureDevOpsWikiTool):
                     "message": f"Page renamed from '{old_page_name}' to '{new_page_name}'",
                 }
             except AzureDevOpsServiceError as e:
-                if "The version '{0}' either is invalid or does not exist." in str(e):
+                if INVALID_VERSION_ERROR in str(e):
                     # Retry the request without version_descriptor
                     result = self._client.create_page_move(
                         project=self.config.project,
@@ -251,130 +386,114 @@ class RenameWikiPageTool(BaseAzureDevOpsWikiTool):
             raise ToolException(f"Unable to rename wiki page: {str(e)}")
 
 
+class CreateWikiPageTool(BaseAzureDevOpsWikiTool):
+    """Tool to create a new wiki page in Azure DevOps."""
+
+    name: str = CREATE_WIKI_PAGE_TOOL.name
+    description: str = CREATE_WIKI_PAGE_TOOL.description
+    args_schema: Type[BaseModel] = CreatePageInput
+
+    def execute(
+        self,
+        wiki_identified: str,
+        parent_page_path: str,
+        new_page_name: str,
+        page_content: str,
+        version_identifier: str,
+        version_type: str = "branch",
+    ):
+        """Create a new ADO wiki page under the specified parent page."""
+        try:
+            # Create wiki if needed
+            error = self._create_wiki_if_not_exists(wiki_identified)
+            if error:
+                raise ToolException(error)
+
+            # Try to extract page ID from parent path format like '/10330/This-is-sub-page'
+            page_id = self._extract_page_id_from_path(parent_page_path)
+
+            if page_id is not None:
+                # Get full hierarchical path using page ID
+                logger.info(
+                    f"Extracted page ID {page_id} from parent path, discovering full path..."
+                )
+                parent_page_path = self._get_full_path_from_id(wiki_identified, page_id)
+                logger.info(f"Discovered full parent path: {parent_page_path}")
+
+            # Construct the full path for the new page
+            if parent_page_path == "/":
+                full_path = f"/{new_page_name}"
+            else:
+                # Ensure parent path starts with /
+                parent = (
+                    parent_page_path if parent_page_path.startswith("/") else f"/{parent_page_path}"
+                )
+                full_path = f"{parent}/{new_page_name}"
+
+            logger.info(f"Creating new page at path: {full_path}")
+
+            # Create the page
+            try:
+                result = self._client.create_or_update_page(
+                    project=self.config.project,
+                    wiki_identifier=wiki_identified,
+                    path=full_path,
+                    parameters=WikiPageCreateOrUpdateParameters(content=page_content),
+                    version=None,  # New page, no version
+                    version_descriptor=GitVersionDescriptor(
+                        version=version_identifier, version_type=version_type
+                    ),
+                )
+                return {
+                    "response": result,
+                    "message": f"Page '{full_path}' has been created successfully",
+                }
+            except AzureDevOpsServiceError as e:
+                if INVALID_VERSION_ERROR in str(e):
+                    # Retry without version descriptor
+                    result = self._client.create_or_update_page(
+                        project=self.config.project,
+                        wiki_identifier=wiki_identified,
+                        path=full_path,
+                        parameters=WikiPageCreateOrUpdateParameters(content=page_content),
+                        version=None,
+                    )
+                    return {
+                        "response": result,
+                        "message": f"Page '{full_path}' has been created successfully (without version)",
+                    }
+                else:
+                    raise
+        except Exception as e:
+            error_msg = f"Unable to create wiki page: {str(e)}"
+            logger.error(error_msg)
+            raise ToolException(error_msg)
+
+
 class ModifyWikiPageTool(BaseAzureDevOpsWikiTool):
-    """Tool to create or update wiki page in Azure DevOps."""
+    """Tool to update existing wiki page in Azure DevOps."""
 
     name: str = MODIFY_WIKI_PAGE_TOOL.name
     description: str = MODIFY_WIKI_PAGE_TOOL.description
     args_schema: Type[BaseModel] = ModifyPageInput
 
-    def _create_wiki_if_not_exists(self, wiki_identified: str) -> Optional[str]:
-        """Create wiki if it doesn't exist."""
-        all_wikis = [wiki.name for wiki in self._client.get_all_wikis(project=self.config.project)]
-        if wiki_identified in all_wikis:
-            return None
+    def _get_page_version(self, wiki_identified: str, page_name: str) -> str:
+        """
+        Get page version (eTag) if page exists.
 
-        logger.info(f"Wiki name '{wiki_identified}' doesn't exist. New wiki will be created.")
-        try:
-            project_id = self._get_project_id()
-            if not project_id:
-                return "Project ID has not been found."
-
-            self._client.create_wiki(
-                project=self.config.project,
-                wiki_create_params=WikiCreateParametersV2(
-                    name=wiki_identified, project_id=project_id
-                ),
-            )
-            logger.info(f"Wiki '{wiki_identified}' has been created")
-            return None
-        except Exception as create_wiki_e:
-            error_msg = f"Unable to create new wiki due to error: {create_wiki_e}"
-            logger.error(error_msg)
-            return error_msg
-
-    def _get_project_id(self) -> Optional[str]:
-        """Get project ID from project name."""
-        projects = self._core_client.get_projects()
-        for project in projects:
-            if project.name == self.config.project:
-                return project.id
-        return None
-
-    def _get_page_version(
-        self, wiki_identified: str, page_name: str
-    ) -> tuple[Optional[str], Optional[str]]:
-        """Get page version (eTag) if page exists."""
+        Raises ToolException if page doesn't exist.
+        """
         try:
             page = self._client.get_page(
                 project=self.config.project, wiki_identifier=wiki_identified, path=page_name
             )
             version = page.eTag
             logger.info(f"Existing page found with eTag: {version}")
-            return version, None
-        except Exception as get_page_e:
-            if "Ensure that the path of the page is correct and the page exists" in str(get_page_e):
-                logger.info("Path is not found. New page will be created")
-                return None, None
-            error_msg = f"Unable to extract page by path {page_name}: {str(get_page_e)}"
+            return version
+        except Exception as e:
+            error_msg = f"Page '{page_name}' not found. Use 'create_wiki_page' tool to create new pages. Error: {str(e)}"
             logger.error(error_msg)
-            return None, error_msg
-
-    def _create_or_update_page(
-        self,
-        wiki_identified: str,
-        page_name: str,
-        page_content: str,
-        version: Optional[str],
-        version_identifier: str,
-        version_type: str,
-    ) -> dict:
-        """Create or update the wiki page."""
-        try:
-            return self._try_create_or_update_with_version(
-                wiki_identified, page_name, page_content, version, version_identifier, version_type
-            )
-        except AzureDevOpsServiceError as e:
-            if "The version '{0}' either is invalid or does not exist." in str(e):
-                return self._try_create_or_update_without_version(
-                    wiki_identified, page_name, page_content, version
-                )
-            raise
-
-    def _try_create_or_update_with_version(
-        self,
-        wiki_identified: str,
-        page_name: str,
-        page_content: str,
-        version: Optional[str],
-        version_identifier: str,
-        version_type: str,
-    ) -> dict:
-        """Attempt to create or update page with version information."""
-        result = self._client.create_or_update_page(
-            project=self.config.project,
-            wiki_identifier=wiki_identified,
-            path=page_name,
-            parameters=WikiPageCreateOrUpdateParameters(content=page_content),
-            version=version,
-            version_descriptor=GitVersionDescriptor(
-                version=version_identifier, version_type=version_type
-            ),
-        )
-        return self._create_result_dict(result, page_name, version)
-
-    def _try_create_or_update_without_version(
-        self, wiki_identified: str, page_name: str, page_content: str, version: Optional[str]
-    ) -> dict:
-        """Attempt to create or update page without version information."""
-        result = self._client.create_or_update_page(
-            project=self.config.project,
-            wiki_identifier=wiki_identified,
-            path=page_name,
-            parameters=WikiPageCreateOrUpdateParameters(content=page_content),
-            version=version,
-        )
-        return self._create_result_dict(result, page_name, version, with_version=False)
-
-    def _create_result_dict(
-        self, result, page_name: str, version: Optional[str], with_version: bool = True
-    ) -> dict:
-        """Create a standardized result dictionary."""
-        return {
-            "response": result,
-            "message": f"Page '{page_name}' has been {'updated' if version else 'created'}"
-            f"{' (without version)' if not with_version else ''}",
-        }
+            raise ToolException(error_msg)
 
     def execute(
         self,
@@ -384,22 +503,53 @@ class ModifyWikiPageTool(BaseAzureDevOpsWikiTool):
         version_identifier: str,
         version_type: str = "branch",
     ):
-        """Create or Update ADO wiki page content."""
+        """Update existing ADO wiki page content."""
         try:
-            # Create wiki if needed
-            error = self._create_wiki_if_not_exists(wiki_identified)
-            if error:
-                return error
+            # Try to extract page ID from path format like '/10330/This-is-sub-page'
+            page_id = self._extract_page_id_from_path(page_name)
 
-            # Get page version
-            version, error = self._get_page_version(wiki_identified, page_name)
-            if error:
-                return error
+            if page_id is not None:
+                # Get full hierarchical path using page ID
+                logger.info(f"Extracted page ID {page_id} from path, discovering full path...")
+                full_path = self._get_full_path_from_id(wiki_identified, page_id)
+                logger.info(f"Discovered full path: {full_path}")
+                page_name = full_path
 
-            # Create or update the page
-            return self._create_or_update_page(
-                wiki_identified, page_name, page_content, version, version_identifier, version_type
-            )
+            # Get page version (will fail if page doesn't exist)
+            version = self._get_page_version(wiki_identified, page_name)
+
+            # Update the page
+            try:
+                result = self._client.create_or_update_page(
+                    project=self.config.project,
+                    wiki_identifier=wiki_identified,
+                    path=page_name,
+                    parameters=WikiPageCreateOrUpdateParameters(content=page_content),
+                    version=version,
+                    version_descriptor=GitVersionDescriptor(
+                        version=version_identifier, version_type=version_type
+                    ),
+                )
+                return {
+                    "response": result,
+                    "message": f"Page '{page_name}' has been updated successfully",
+                }
+            except AzureDevOpsServiceError as e:
+                if INVALID_VERSION_ERROR in str(e):
+                    # Retry without version descriptor
+                    result = self._client.create_or_update_page(
+                        project=self.config.project,
+                        wiki_identifier=wiki_identified,
+                        path=page_name,
+                        parameters=WikiPageCreateOrUpdateParameters(content=page_content),
+                        version=version,
+                    )
+                    return {
+                        "response": result,
+                        "message": f"Page '{page_name}' has been updated successfully (without version)",
+                    }
+                else:
+                    raise
         except Exception as e:
             error_msg = f"Unable to modify wiki page: {str(e)}"
             logger.error(error_msg)
