@@ -2,12 +2,12 @@ from typing import Optional
 
 from pydantic import Field
 
-from codemie_tools.base.models import CodeMieToolConfig
+from codemie_tools.base.models import CodeMieToolConfig, RequiredField, CredentialTypes
 
 
 class GithubConfig(CodeMieToolConfig):
-    token: str = Field(
-        default="",
+    credential_type: CredentialTypes = Field(default=CredentialTypes.GIT, exclude=True, frozen=True)
+    token: str = RequiredField(
         description="GitHub Personal Access Token with appropriate scopes for repository access",
         json_schema_extra={
             "sensitive": True,
