@@ -54,9 +54,9 @@ EXCEL_TOOL = ToolMetadata(
     name="excel_tool",
     description="""
     Use this tool to extract and analyze content from Excel files (XLS, XLSX). The tool processes spreadsheet data,
-    converting it into readable markdown tables. It can handle multiple sheets and filter out empty rows and columns
-    for better readability. Ideal for tasks requiring analysis, data extraction, or question-answering based on
-    tabular data in Excel format.
+    converting it into readable markdown tables. It can handle multiple sheets, filter out empty rows and columns,
+    and filter rows based on multiple cell values with AND logic. Works with pivot tables and complex Excel layouts.
+    Ideal for tasks requiring analysis, data extraction, or question-answering based on tabular data in Excel format.
 
     Key capabilities:
     - Process all sheets or specify sheets by name using the `sheet_names` parameter
@@ -64,9 +64,20 @@ EXCEL_TOOL = ToolMetadata(
     - Access a specific sheet by its index (0-based) using `sheet_index` parameter
     - Get comprehensive statistics about the Excel file with `get_stats=True` (includes sheet counts, column names, data types, sample values)
     - Control sheet visibility with `visible_only=True/False` parameter to include or exclude hidden sheets
+    - **Filter rows by multiple values**: Use `filter_values` (list) to include only rows containing ALL specified values (AND logic)
+    - **Filter modes**: Control matching with `filter_mode`: 'exact' (default) for exact matches, 'contains' for substring matches
+    - Works with complex layouts: Filtering searches across all cells in a row, not just specific columns
+    - Each filter value can appear in any cell of the row (OR logic within each value)
     - Automatically normalize column names for better readability
     - Process multiple Excel files with clear separation between documents
     - Intelligent data cleaning to remove empty rows and columns
+
+    Examples:
+    - Single exact match: `filter_values=["NATI-5DME"]` to get rows containing "NATI-5DME"
+    - Multiple values (AND): `filter_values=["Critical", "Open", "Bug"]` returns only rows containing all three values
+    - Substring match: `filter_values=["NATI"]` with `filter_mode="contains"` to get rows containing "NATI" anywhere
+    - Complex filtering: `filter_values=["Sprint 42", "In Progress", "John"]` finds rows with all three criteria
+    - Status + Type filtering: `filter_values=["Complete", "Feature"]` for rows matching both criteria
     """,
     label="Excel Processing Tool",
 )
