@@ -1,20 +1,18 @@
+from codemie_tools.base.models import CodeMieToolConfig, RequiredField, CredentialTypes
+
 from pydantic import Field
 
-from codemie_tools.base.models import CodeMieToolConfig
-
-
 class EmailToolConfig(CodeMieToolConfig):
-    url: str = Field(
+    credential_type: CredentialTypes = Field(default=CredentialTypes.EMAIL, exclude=True, frozen=True)
+    url: str = RequiredField(
         description="SMTP server URL including port, e.g. smtp.gmail.com:587",
         json_schema_extra={"placeholder": "smtp.gmail.com:587"},
     )
-    smtp_username: str = Field(
-        default="",
+    smtp_username: str = RequiredField(
         description="SMTP server username/email",
         json_schema_extra={"placeholder": "user@example.com"},
     )
-    smtp_password: str = Field(
-        default="",
+    smtp_password: str = RequiredField(
         description="SMTP server password or app-specific password for accounts with 2FA",
         json_schema_extra={"placeholder": "password", "sensitive": True},
     )
