@@ -2,7 +2,7 @@ from codemie_tools.base.models import ToolMetadata
 from codemie_tools.notification.email.models import EmailToolConfig
 
 EMAIL_TOOL = ToolMetadata(
-    name="email_tool",
+    name="Email",
     description="Use this tool when you need to send an email notification via SMTP. Supports TO, CC, BCC, and custom FROM address.",
     label="Email",
     user_description="""The purpose of the email tool is to send emails using SMTP protocol. 
