@@ -1,9 +1,10 @@
 from pydantic import Field
 
-from codemie_tools.base.models import CodeMieToolConfig
+from codemie_tools.base.models import CodeMieToolConfig, CredentialTypes
 
 
 class TelegramConfig(CodeMieToolConfig):
+    credential_type: CredentialTypes = Field(default=CredentialTypes.TELEGRAM, exclude=True, frozen=True)
     bot_token: str = Field(
         default="",
         alias="token",
