@@ -2,11 +2,12 @@ from typing import Optional
 
 from pydantic import Field, model_validator
 
-from codemie_tools.base.models import CodeMieToolConfig
+from codemie_tools.base.models import CredentialTypes, CodeMieToolConfig
 
 
 class OpenApiConfig(CodeMieToolConfig):
     """Configuration for OpenAPI tools."""
+    credential_type: CredentialTypes = Field(default=CredentialTypes.OPEN_API, exclude=True, frozen=True)
 
     model_config = {
         "populate_by_name": True,  # Allow initialization using either field name or alias
